##  Endpoint
After activating the AI Agent API, you can upload AI agent cards by making a POST request to the following endpoint:

```
https://{SUBDOMAIN}.leanix.net/services/discovery-ai-agents/v1/agents/a2a/cards
```



To learn how to get your base URL, visit [Base URL](https://help.sap.com/docs/leanix/ea/base-url?locale=en-US&state=PRODUCTION&version=CLOUD "Learn about the SAP LeanIX base URL and how to get your subdomain value.").
